@@ -6,6 +6,7 @@ from flask import request
 
 from .authentication import get_user_email
 from arcane.pubsub.utils import pubsub_json_message_decoder
+from flask_log_request_id import current_request_id
 
 
 def catch_exceptions_service(service: str, pubsub_subscriber: bool=False, auth_enabled=True) -> Callable:
@@ -41,3 +42,23 @@ def catch_exceptions_service(service: str, pubsub_subscriber: bool=False, auth_e
                 raise e
         return wrapper
     return catch_exceptions
+
+
+def add_id_to_exceptions() -> Callable:
+    """ Catch if an exception is raised after an endpoint call and add the request id
+    """
+    def catch_exceptions(job_func: Callable) -> Callable:
+        @functools.wraps(job_func)
+        def wrapper(*args, **kwargs):
+            try:
+                return job_func(*args, **kwargs)
+            except Exception as e:
+                request_id = None
+                import sys
+                try:
+                    request_id = current_request_id()
+                except KeyError:
+                    pass
+                raise type(e)(f"[{request_id}]: {str(e)}").with_traceback(sys.exc_info()[2])
+        return wrapper
+    return catch_exceptions
